==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/Input/mpeg/translations/mpeg_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>DecoderMPEGFactory</name>
    <message>
        <location filename="../decodermpegfactory.cpp" line="179"/>
        <source>MPEG Plugin</source>
        <translation>Engadido MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="182"/>
        <source>MPEG Files</source>
        <translation>Ficheiros MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="400"/>
        <source>About MPEG Audio Plugin</source>
        <translation>Sobre o engadido MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="401"/>
        <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
        <translation>Decodificador de audio MPEG 1.0/2.0/2.5 capa 1/2/3</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="402"/>
        <source>Compiled against:</source>
        <translation>Compilado usando:</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="411"/>
        <source>mpg123, API version: %1</source>
        <translation>mpg123, versión API: %1</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="415"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="416"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>Código fonte baseado nos proxectos mq3 e madplay</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="65"/>
        <location filename="../mpegmetadatamodel.cpp" line="68"/>
        <location filename="../mpegmetadatamodel.cpp" line="71"/>
        <location filename="../mpegmetadatamodel.cpp" line="74"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="77"/>
        <source>Protection</source>
        <translation>Protección</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="79"/>
        <source>Original</source>
        <translation>Orixinal</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>Preferencias do engadido MPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Decoder</source>
        <translation>Decodificador</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>MAD</source>
        <translation>LOCO</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>MPG123</source>
        <translation>MPG123</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="77"/>
        <source>Tag Priority</source>
        <translation>Prioridade de etiquetas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>First:</source>
        <translation>Primeira:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="109"/>
        <location filename="../settingsdialog.ui" line="158"/>
        <location filename="../settingsdialog.ui" line="207"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="114"/>
        <location filename="../settingsdialog.ui" line="163"/>
        <location filename="../settingsdialog.ui" line="212"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="119"/>
        <location filename="../settingsdialog.ui" line="168"/>
        <location filename="../settingsdialog.ui" line="217"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="173"/>
        <location filename="../settingsdialog.ui" line="222"/>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>Second:</source>
        <translation>Segunda:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="187"/>
        <source>Third:</source>
        <translation>Terceira:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="243"/>
        <source>Merge selected tag types</source>
        <translation>Combinalos tipos de etiqueta selecionados</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="262"/>
        <source>Encodings</source>
        <translation>Codificacións</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="274"/>
        <source>ID3v1 encoding:</source>
        <translation>Codificación ID3v1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="300"/>
        <source>ID3v2 encoding:</source>
        <translation>Codificación ID3v2:</translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Input/mpeg/translations/mpeg_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>DecoderMPEGFactory</name>
    <message>
        <location filename="../decodermpegfactory.cpp" line="180"/>
        <source>MPEG Plugin</source>
        <translation>Engadido MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="183"/>
        <source>MPEG Files</source>
        <translation>Ficheiros MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="412"/>
        <source>About MPEG Audio Plugin</source>
        <translation>Sobre o engadido MPEG</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="413"/>
        <source>MPEG 1.0/2.0/2.5 layer 1/2/3 audio decoder</source>
        <translation>Decodificador de audio MPEG 1.0/2.0/2.5 capa 1/2/3</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="414"/>
        <source>Compiled against:</source>
        <translation>Compilado usando:</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="423"/>
        <source>mpg123, API version: %1</source>
        <translation>mpg123, versión API: %1</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="427"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../decodermpegfactory.cpp" line="428"/>
        <source>Source code based on mq3 and madplay projects</source>
        <translation>Código fonte baseado nos proxectos mq3 e madplay</translation>
    </message>
</context>
<context>
    <name>MPEGMetaDataModel</name>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="66"/>
        <location filename="../mpegmetadatamodel.cpp" line="69"/>
        <location filename="../mpegmetadatamodel.cpp" line="72"/>
        <location filename="../mpegmetadatamodel.cpp" line="75"/>
        <source>Mode</source>
        <translation>Modo</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="78"/>
        <source>Protection</source>
        <translation>Protección</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="79"/>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <location filename="../mpegmetadatamodel.cpp" line="80"/>
        <source>Original</source>
        <translation>Orixinal</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>MPEG Plugin Settings</source>
        <translation>Preferencias do engadido MPEG</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Decoder</source>
        <translation>Decodificador</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>MAD</source>
        <translation>LOCO</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>MPG123</source>
        <translation>MPG123</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>Enable CRC checking</source>
        <translation>Habilitar comprobación CRC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="87"/>
        <source>Tag Priority</source>
        <translation>Prioridade de etiquetas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>First:</source>
        <translation>Primeira:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="119"/>
        <location filename="../settingsdialog.ui" line="168"/>
        <location filename="../settingsdialog.ui" line="217"/>
        <source>ID3v1</source>
        <translation>ID3v1</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <location filename="../settingsdialog.ui" line="173"/>
        <location filename="../settingsdialog.ui" line="222"/>
        <source>ID3v2</source>
        <translation>ID3v2</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="129"/>
        <location filename="../settingsdialog.ui" line="178"/>
        <location filename="../settingsdialog.ui" line="227"/>
        <source>APE</source>
        <translation>APE</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="134"/>
        <location filename="../settingsdialog.ui" line="183"/>
        <location filename="../settingsdialog.ui" line="232"/>
        <source>Disabled</source>
        <translation>Desactivado</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="148"/>
        <source>Second:</source>
        <translation>Segunda:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="197"/>
        <source>Third:</source>
        <translation>Terceira:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="253"/>
        <source>Merge selected tag types</source>
        <translation>Combinalos tipos de etiqueta selecionados</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="272"/>
        <source>Encodings</source>
        <translation>Codificacións</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="333"/>
        <source>ID3v1 encoding:</source>
        <translation>Codificación ID3v1:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="343"/>
        <source>Try to detect encoding</source>
        <translation>Tentar detectar a codificación</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="294"/>
        <source>ID3v2 encoding:</source>
        <translation>Codificación ID3v2:</translation>
    </message>
</context>
</TS>
